# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.s3_connection_settings_api_dto import S3ConnectionSettingsApiDto

class TestS3ConnectionSettingsApiDto(unittest.TestCase):
    """S3ConnectionSettingsApiDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> S3ConnectionSettingsApiDto:
        """Test S3ConnectionSettingsApiDto
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `S3ConnectionSettingsApiDto`
        """
        model = S3ConnectionSettingsApiDto()
        if include_optional:
            return S3ConnectionSettingsApiDto(
                region = 'o',
                access_key = 'o',
                secret_key = 'o',
                url = 'o',
                type = ''
            )
        else:
            return S3ConnectionSettingsApiDto(
                region = 'o',
                access_key = 'o',
                secret_key = 'o',
                url = 'o',
        )
        """

    def testS3ConnectionSettingsApiDto(self):
        """Test S3ConnectionSettingsApiDto"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
